==> openshift-model-console-5.7.4-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CLIDownloadLinkBuilder extends io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluentImpl<io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.CLIDownloadLink,io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkBuilder>{
  public CLIDownloadLinkBuilder() {
    this(false);
  }
  public CLIDownloadLinkBuilder(java.lang.Boolean validationEnabled) {
    this(new CLIDownloadLink(), validationEnabled);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent) {
    this(fluent, false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CLIDownloadLink(), validationEnabled);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this(fluent, instance, false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHref(instance.getHref()); 
    fluent.withText(instance.getText()); 
    this.validationEnabled = validationEnabled; 
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this(instance,false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.CLIDownloadLink build() {
    CLIDownloadLink buildable = new CLIDownloadLink(fluent.getHref(),fluent.getText());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CLIDownloadLinkBuilder that = (CLIDownloadLinkBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/CLIDownloadLinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CLIDownloadLinkBuilder extends io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluentImpl<io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.CLIDownloadLink,io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkBuilder>{
  public CLIDownloadLinkBuilder() {
    this(false);
  }
  public CLIDownloadLinkBuilder(java.lang.Boolean validationEnabled) {
    this(new CLIDownloadLink(), validationEnabled);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent) {
    this(fluent, false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CLIDownloadLink(), validationEnabled);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this(fluent, instance, false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHref(instance.getHref()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance) {
    this(instance,false);
  }
  public CLIDownloadLinkBuilder(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.CLIDownloadLinkFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.CLIDownloadLink build() {
    CLIDownloadLink buildable = new CLIDownloadLink(fluent.getHref(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CLIDownloadLinkBuilder that = (CLIDownloadLinkBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
